@@ -27,6 +27,14 @@ class MySqlConnection(BaseSqlConnection):
     def _getConnectionStr(self):
         return 'mysql+pymysql://{user}:{password}@{db}'.format(user=self.user, password=self.passwd, db=self.db)
 
+class SQLiteConnection(BaseSqlConnection):
+    def __init__(self, filePath):
+        BaseSqlConnection.__init__(self, None, None, None)
+        self.filePath = filePath
+
+    def _getConnectionStr(self):
+        return 'sqlite:////{filePath}?check_same_thread=False'.format(filePath=self.filePath)
+
 class OracleSqlConnection(BaseSqlConnection):
     def __init__(self, user, passwd, db):
         BaseSqlConnection.__init__(self, user, passwd, db)
@@ -98,12 +106,12 @@ class BaseSqlConnector():
         trans = self.conn.begin()
         try:
             batch = []
-            # we have only key name, original_key, streamId, it means that the key was deleted
-            isAddBatch = True if data[0][OP_KEY] == OPERATION_UPDATE_REPLICATE else False
+            isAddBatch = True if data[0]['value'][OP_KEY] == OPERATION_UPDATE_REPLICATE else False
             query = self.addQuery if isAddBatch else self.delQuery
             lastStreamId = None
-            for x in data:
-                lastStreamId = x.pop('streamId', None)## pop the stream id out of the record, we do not need it.
+            for d in data:
+                x = d['value']
+                lastStreamId = d.pop('id', None)## pop the stream id out of the record, we do not need it.
                 if self.shouldCompareId and CompareIds(self.exactlyOnceLastId, lastStreamId) >= 0:
                     WriteBehindLog('Skip %s as it was already writen to the backend' % lastStreamId)
                     continue
@@ -163,6 +171,10 @@ class MySqlConnector(BaseSqlConnector):
         if self.exactlyOnceTableName is not None:
             self.exactlyOnceQuery = GetUpdateQuery(self.exactlyOnceTableName, {'val', 'val'}, 'id')
 
+class SQLiteConnector(MySqlConnector):
+    def __init__(self, connection, tableName, pk, exactlyOnceTableName=None):
+        MySqlConnector.__init__(self, connection, tableName, pk, exactlyOnceTableName)
+
 class OracleSqlConnector(BaseSqlConnector):
     def __init__(self, connection, tableName, pk, exactlyOnceTableName=None):
         BaseSqlConnector.__init__(self, connection, tableName, pk, exactlyOnceTableName)
